pub enum ApplyPatchError {
ParseError(ParseError),
IoError(IoError),
ComputeReplacements(String),
PathUri(PathUriParseError),
ImplicitInvocation,
}Variants
ParseError(ParseError)
IoError(IoError)
ComputeReplacements(String)
Error that occurs while computing replacements when applying patch chunks
PathUri(PathUriParseError)
A patch path could not be resolved as a path URI.
ImplicitInvocation
A raw patch body was provided without an explicit apply_patch invocation.