pub struct AffectedPaths {
pub added: Vec<PathBuf>,
pub modified: Vec<PathBuf>,
pub deleted: Vec<PathBuf>,
}Expand description
Applies each parsed patch hunk to the filesystem. Returns an error if any of the changes could not be applied. Tracks file paths affected by applying a patch, preserving the path spelling from the patch for user-facing summaries.
Fields
added: Vec<PathBuf>modified: Vec<PathBuf>deleted: Vec<PathBuf>Auto Trait Implementations
impl Freeze for AffectedPaths
impl RefUnwindSafe for AffectedPaths
impl Send for AffectedPaths
impl Sync for AffectedPaths
impl Unpin for AffectedPaths
impl UnsafeUnpin for AffectedPaths
impl UnwindSafe for AffectedPaths