pub struct ApplyPatchAction {
pub patch: String,
pub cwd: PathUri,
/* private fields */
}Expand description
ApplyPatchAction is the result of parsing an apply_patch command. By
construction, all paths should be absolute paths.
Fields
patch: StringThe raw patch argument that can be used to apply the patch. i.e., if the original arg was parsed in “lenient” mode with a heredoc, this should be the value without the heredoc wrapper.
cwd: PathUriThe working directory that was used to resolve relative paths in the patch.
Implementations
Sourceimpl ApplyPatchAction
impl ApplyPatchAction
pub fn is_empty(&self) -> bool
Sourcepub fn changes(&self) -> &HashMap<PathUri, ApplyPatchFileChange>
pub fn changes(&self) -> &HashMap<PathUri, ApplyPatchFileChange>
Returns the changes that would be made by applying the patch.
Sourcepub fn new_add_for_test(path: &PathUri, content: String) -> Self
pub fn new_add_for_test(path: &PathUri, content: String) -> Self
Should be used exclusively for testing. (Not worth the overhead of creating a feature flag for this.)