pub struct UpdateFileChunk {
pub change_context: Option<String>,
pub old_lines: Vec<String>,
pub new_lines: Vec<String>,
pub is_end_of_file: bool,
}Fields
change_context: Option<String>A single line of context used to narrow down the position of the chunk (this is usually a class, method, or function definition.)
old_lines: Vec<String>A contiguous block of lines that should be replaced with new_lines.
old_lines must occur strictly after change_context.
new_lines: Vec<String>is_end_of_file: boolIf set to true, old_lines must occur at the end of the source file.
(Tolerance around trailing newlines should be encouraged.)