Structs
- Affected
Paths - Applies each parsed patch hunk to the filesystem. Returns an error if any of the changes could not be applied. Tracks file paths affected by applying a patch, preserving the path spelling from the patch for user-facing summaries.
- Applied
Patch Change - A committed file change, preserved in the order it was applied.
- Applied
Patch Delta - Textual file changes that were actually committed while applying a patch.
- Apply
Patch Action - ApplyPatchAction is the result of parsing an
apply_patchcommand. By construction, all paths should be absolute paths. - Apply
Patch Args - Both the raw PATCH argument to
apply_patchas well as the PATCH argument parsed into hunks. - Apply
Patch Failure - A failed patch application together with the textual mutations that were definitely committed before the failure was observed.
- Apply
Patch File Update - Intended result of a file update for apply_patch.
- IoError
- Streaming
Patch Parser - Update
File Chunk
Enums
Constants
- CODEX_
CORE_ APPLY_ PATCH_ ARG1 - Special argv[1] flag used when the Codex executable self-invokes to run the
internal
apply_patchpath.
Functions
- apply_
hunks - Applies hunks and continues to update stdout/stderr
- apply_
patch - Applies the patch and prints the result to stdout/stderr.
- main
- maybe_
parse_ apply_ patch_ verified cwdmust identify an absolute environment-native path so relative patch paths can be resolved without projecting them onto the app-server or exec-server host.- parse_
patch - print_
summary - Print the summary of changes in git-style format. Write a summary of changes to the given writer.
- unified_
diff_ from_ chunks - unified_
diff_ from_ chunks_ with_ context - verify_
apply_ patch_ args